Learn R Programming

tidystopwords (version 0.9.1)

list_supported_languages: Listing of languages supported by list_supported_languages by their names and ISO-639 codes in a data frame.

Description

Generate a data frame containing language names and their corresponding ISO-639 codes, with numbers of stop words for the given language

Usage

list_supported_languages()

Arguments

Value

A grouped tibble (data frame) with three columns:

References

The underlying data frame `multilingual_stoplist` is based on the official release of Version 2.8 of Universal Dependencies.

https://universaldependencies.org

Zeman, Daniel; et al., 2021, Universal Dependencies 2.8.1, LINDAT/CLARIAH-CZ digital library at the Institute of Formal and Applied Linguistics (<U+00DA>FAL), Faculty of Mathematics and Physics, Charles University, http://hdl.handle.net/11234/1-3687.

See Also

generate_stoplist, multilingual_stoplist

Examples

Run this code
# NOT RUN {
list_supported_languages()
# }

Run the code above in your browser using DataLab